@@ -158,7 +158,7 @@ class HeatControl:
 
         con.commit()
         con.close()
-        
+
     def initialize_gpio(self):
         GPIO.cleanup()
         GPIO.setmode(GPIO.BCM)
@@ -226,23 +226,31 @@ class HeatControl:
 
                 if consecutive_hours <= MAX_CONSECUTIVE_ZERO_POWER_HOURS:
                     add_to_zero_power_hours = True
+                else:
+                    print(
+                        f"Consecutive hours {consecutive_hours} is above max consecutive hours {MAX_CONSECUTIVE_ZERO_POWER_HOURS}. Not adding {hour['Hour']} to ZeroPowerHours"
+                    )
 
             # Add to ZeroPowerHours always if price is above ultimate max price
             if hour["PriceWithTax"] > ULTIMATE_HIGHEST_PRICE:
+                print(f"Price {hour['PriceWithTax']} is above ultimate max price")
                 add_to_zero_power_hours = True
 
             # Keep heating on if price is below ultimate min price
             if hour["PriceWithTax"] < ULTIMATE_LOWEST_PRICE:
+                print(f"Price {hour['PriceWithTax']} is below ultimate min price")
                 continue
 
             if add_to_zero_power_hours:
 
                 # Don't add more than SAFE_ZERO_POWER_HOURS
                 if len(self.ZeroPowerHours) < SAFE_ZERO_POWER_HOURS:
+                    print(f"Adding {hour['Hour']} to ZeroPowerHours")
                     self.ZeroPowerHours.append(hour)
                 add_to_zero_power_hours = False
 
             elif len(self.HalfPowerHours) < HALF_POWER_HOURS:
+                print(f"Adding {hour['Hour']} to HalfPowerHours")
                 self.HalfPowerHours.append(hour)
 
     def set_heat(self):
